@@ -363,7 +363,6 @@ class TacotronLoss(torch.nn.Module):
         alignments_backwards,
         input_lens,
     ):
-
         # decoder outputs linear or mel spectrograms for Tacotron and Tacotron2
         # the target should be set acccordingly
         postnet_target = linear_input if self.config.model.lower() in ["tacotron"] else mel_input
@@ -801,6 +800,10 @@ class ForwardTTSLoss(nn.Module):
             self.pitch_loss = MSELossMasked(False)
             self.pitch_loss_alpha = c.pitch_loss_alpha
 
+        if c.model_args.use_energy:
+            self.energy_loss = MSELossMasked(False)
+            self.energy_loss_alpha = c.energy_loss_alpha
+
         if c.use_ssim_loss:
             self.ssim = SSIMLoss() if c.use_ssim_loss else None
             self.ssim_loss_alpha = c.ssim_loss_alpha
@@ -826,6 +829,8 @@ class ForwardTTSLoss(nn.Module):
         dur_target,
         pitch_output,
         pitch_target,
+        energy_output,
+        energy_target,
         input_lens,
         alignment_logprob=None,
         alignment_hard=None,
@@ -855,6 +860,11 @@ class ForwardTTSLoss(nn.Module):
             loss = loss + self.pitch_loss_alpha * pitch_loss
             return_dict["loss_pitch"] = self.pitch_loss_alpha * pitch_loss
 
+        if hasattr(self, "energy_loss") and self.energy_loss_alpha > 0:
+            energy_loss = self.energy_loss(energy_output.transpose(1, 2), energy_target.transpose(1, 2), input_lens)
+            loss = loss + self.energy_loss_alpha * energy_loss
+            return_dict["loss_energy"] = self.energy_loss_alpha * energy_loss
+
         if hasattr(self, "aligner_loss") and self.aligner_loss_alpha > 0:
             aligner_loss = self.aligner_loss(alignment_logprob, input_lens, decoder_output_lens)
             loss = loss + self.aligner_loss_alpha * aligner_loss
